package de.fitko.fitconnect.api.services.metadata;

import de.fitko.fitconnect.api.domain.model.metadata.Metadata;
import de.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import de.fitko.fitconnect.api.domain.model.metadata.data.Data;
import de.fitko.fitconnect.api.domain.model.submission.SubmissionSubmit;

import java.util.List;

/**
 * Provides the generation of correct and valid {@link Metadata} for a {@link SubmissionSubmit}
 *
 * @see
 * <a href="https://docs.fitko.de/fit-connect/docs/metadataoverview">Metadata</a> and
 * <a href="https://docs.fitko.de/fit-connect/docs/getting-started/submission/structure">Structure of a submission</a>
 */
public interface MetadataService {

    /**
     * Generates valid metadata for a submission including its JWE-encrypted data and attachments.
     *
     * @param data the payload (json or xml)
     * @param attachments list of 0..n attachments as binary data
     * @return {@link Metadata} with hashes
     */
    Metadata createMetadata(final Data data, final List<Attachment> attachments);

    /**
     * Uploads metadata to FIT-Connect API.
     *
     * @param metadata generated with {@link #createMetadata(Data, List)}
     */
    void uploadMetadata(final Metadata metadata);
}
